@@ -14,12 +14,10 @@ For more information, access: https://github.com/snakypy/zshpower
 """
 
 from . import __name__
-from os.path import join
 from pathlib import Path
 
-__version__ = "0.1.1"
-
-_PACKAGE = {
+__version__ = "0.1.2"
+__info__ = {
     "name": __name__,
     "url": "https://github.com/snakypy/zshpower",
     "organization_name": "Snakypy",
@@ -39,14 +37,4 @@ _PACKAGE = {
     ],
 }
 
-_HOME = str(Path.home())
-_omz_root_folder = join(_HOME, ".oh-my-zsh")
-_config_root_folder = join(_HOME, f".config/snakypy/zshpower/{__version__}")
-_themes_folder = join(_omz_root_folder, "custom/themes")
-_zsh_rc = join(_HOME, ".zshrc")
-_plugins = ["zsh-syntax-highlighting", "zsh-autosuggestions"]
-_template_dirs = (
-    join(_themes_folder, f"{__name__}"),
-    join(_themes_folder, f"{__name__}/sections"),
-    join(_themes_folder, f"{__name__}/lib"),
-)
+HOME = str(Path.home())
