@@ -2,7 +2,7 @@ from functools import wraps
 from sys import exit
 from os.path import exists, join
 from snakypy import printer, FG
-from zshpower import _PACKAGE, __name__
+from zshpower import __info__, __name__
 
 
 def assign_cli(arguments: callable(object), command: str):
@@ -17,13 +17,13 @@ def assign_cli(arguments: callable(object), command: str):
     return decorator
 
 
-def checking_init(root: str):
+def checking_init_command(root: str):
     def decorator(func):
         @wraps(func)
         def wrapper(*args, **kwargs):
             if not exists(join(root, f"{__name__}.zsh-theme")):
                 printer(
-                    f'Command "{_PACKAGE["name"]} init" has not been started.'
+                    f'Command "{__info__["name"]} init" has not been started.'
                     "Aborted",
                     foreground=FG.WARNING,
                 )
