@@ -9,9 +9,12 @@ function snakypy_ssh () {
     snakypy__ssh_prefix1="$(snakypy::fg red " " "$SNAKYPY__SEPARATOR" "")"
     snakypy__ssh_prefix2="$(snakypy::fg "$SNAKYPY__SSH_PREFIX_COLOR" "" \\
 "$SNAKYPY__SSH_PREFIX_TEXT" " ")"
+
+    ssh_get="$(snakypy::fg "$SNAKYPY__SSH_COLOR" "" "$(snakypy::icon \\
+"\\uf817")SSH" " ")"
+
     if [[ $SSH_CONNECTION ]] &&
-    [[ $SNAKYPY__SSH_INFO_ENABLE == True ]]; then
-        ssh_get="$(snakypy::fg "$SNAKYPY__SSH_COLOR" "" "$(snakypy::icon "\\uf817")SSH" " ")"
+    [[ $SNAKYPY__SSH_ENABLE == True ]]; then
         echo "${snakypy__ssh_prefix1}${snakypy__ssh_prefix2}${ssh_get}"
     fi
 }
